@@ -21,11 +21,7 @@ use walkdir::{DirEntry, WalkDir};
 const MAX_RECURSIVE_DEPTH: usize = 10_000;
 
 // Upload a files to the Network as a Public Blob
-pub(crate) async fn upload_file_to_net(
-    safe: &mut Safe,
-    path: &Path,
-    dry_run: bool,
-) -> Result<XorUrl> {
+pub(crate) async fn upload_file_to_net(safe: &mut Safe, path: &Path) -> Result<XorUrl> {
     let data = fs::read(path).map_err(|err| {
         Error::InvalidInput(format!("Failed to read file from local location: {}", err))
     })?;
@@ -33,14 +29,14 @@ pub(crate) async fn upload_file_to_net(
 
     let mut mime_type_for_xorurl = mime_guess::from_path(&path).first_raw();
     let result = match safe
-        .store_public_bytes(data.to_owned(), mime_type_for_xorurl, dry_run)
+        .store_public_bytes(data.to_owned(), mime_type_for_xorurl)
         .await
     {
         Ok(xorurl) => Ok(xorurl),
         Err(Error::InvalidMediaType(_)) => {
             // Let's then upload it and set media-type to be simply raw content
             mime_type_for_xorurl = None;
-            safe.store_public_bytes(data.clone(), mime_type_for_xorurl, dry_run)
+            safe.store_public_bytes(data.clone(), mime_type_for_xorurl)
                 .await
         }
         other_err => other_err,
@@ -49,10 +45,14 @@ pub(crate) async fn upload_file_to_net(
     // If the upload verification failed, the file could still have been uploaded successfully,
     // thus let's report the error but providing the xorurl for the user to be aware of.
     if let Err(Error::ClientError(ClientError::NotEnoughChunksRetrieved { .. })) = result {
-        // let's obtain the xorurl with using dry-run mode
-        let xorurl = safe
-            .store_public_bytes(data, mime_type_for_xorurl, true)
-            .await?;
+        // Let's obtain the xorurl with using dry-run mode.
+        // Switch dry run mode ON only for this next operation
+        let prev_dry_run_mode = safe.dry_run_mode;
+        safe.dry_run_mode = true;
+        let result = safe.store_public_bytes(data, mime_type_for_xorurl).await;
+        safe.dry_run_mode = prev_dry_run_mode;
+        let xorurl = result?;
+
         Err(Error::ContentUploadVerificationFailed(xorurl))
     } else {
         result
@@ -72,7 +72,6 @@ pub(crate) async fn file_system_dir_walk(
     location: &Path,
     recursive: bool,
     follow_links: bool,
-    dry_run: bool,
 ) -> Result<ProcessedFiles> {
     info!("Reading files from {}", location.display());
 
@@ -129,7 +128,7 @@ pub(crate) async fn file_system_dir_walk(
                     }
 
                     if metadata.file_type().is_file() {
-                        match upload_file_to_net(safe, current_file_path, dry_run).await {
+                        match upload_file_to_net(safe, current_file_path).await {
                             Ok(xorurl) => {
                                 processed_files
                                     .insert(normalised_path, FilesMapChange::Added(xorurl));
@@ -181,7 +180,6 @@ fn valid_depth(entry: &DirEntry, max_depth: usize) -> bool {
 pub(crate) async fn file_system_single_file(
     safe: &mut Safe,
     location: &Path,
-    dry_run: bool,
 ) -> Result<ProcessedFiles> {
     info!("Reading file {}", location.display());
     let (metadata, _) = get_metadata(location, true)?; // follows symlinks.
@@ -195,7 +193,7 @@ pub(crate) async fn file_system_single_file(
             location.display()
         )))
     } else {
-        match upload_file_to_net(safe, location, dry_run).await {
+        match upload_file_to_net(safe, location).await {
             Ok(xorurl) => {
                 processed_files.insert(normalised_path, FilesMapChange::Added(xorurl));
             }
