@@ -29,15 +29,14 @@ impl Safe {
         name: Option<XorName>,
         type_tag: u64,
         private: bool,
-        dry_run: bool,
     ) -> Result<XorUrl> {
         debug!("Creating a Multimap");
         let (xorname, op_batch) = self
             .safe_client
-            .create_register(name, type_tag, None, private, dry_run)
+            .create_register(name, type_tag, None, private, self.dry_run_mode)
             .await?;
 
-        if !dry_run {
+        if !self.dry_run_mode {
             self.safe_client.apply_register_ops(op_batch).await?;
         }
 
@@ -98,7 +97,6 @@ impl Safe {
         multimap_url: &str,
         entry: MultimapKeyValue,
         replace: BTreeSet<EntryHash>,
-        dry_run: bool,
     ) -> Result<EntryHash> {
         debug!("Inserting '{:?}' into Multimap at {}", entry, multimap_url);
         let serialised_entry = rmp_serde::to_vec_named(&entry).map_err(|err| {
@@ -126,7 +124,7 @@ impl Safe {
             .write_to_register(address, data, replace)
             .await?;
 
-        if !dry_run {
+        if !self.dry_run_mode {
             self.safe_client.apply_register_ops(op_batch).await?;
         }
 
@@ -141,7 +139,6 @@ impl Safe {
         &self,
         url: &str,
         to_remove: BTreeSet<EntryHash>,
-        dry_run: bool,
     ) -> Result<EntryHash> {
         debug!("Removing from Multimap at {}: {:?}", url, to_remove);
         let safeurl = Safe::parse_url(url)?;
@@ -160,7 +157,7 @@ impl Safe {
             .write_to_register(address, MULTIMAP_REMOVED_MARK.to_vec(), to_remove)
             .await?;
 
-        if !dry_run {
+        if !self.dry_run_mode {
             self.safe_client.apply_register_ops(op_batch).await?;
         }
 
@@ -254,8 +251,8 @@ mod tests {
     async fn test_multimap_create() -> Result<()> {
         let safe = new_safe_instance().await?;
 
-        let xorurl = safe.multimap_create(None, 25_000, false, false).await?;
-        let xorurl_priv = safe.multimap_create(None, 25_000, true, false).await?;
+        let xorurl = safe.multimap_create(None, 25_000, false).await?;
+        let xorurl_priv = safe.multimap_create(None, 25_000, true).await?;
 
         let key = b"".to_vec();
         let received_data = safe.multimap_get_by_key(&xorurl, &key).await?;
@@ -277,17 +274,17 @@ mod tests {
         let val2 = b"value2".to_vec();
         let key_val2 = (key.clone(), val2.clone());
 
-        let xorurl = safe.multimap_create(None, 25_000, false, false).await?;
-        let xorurl_priv = safe.multimap_create(None, 25_000, true, false).await?;
+        let xorurl = safe.multimap_create(None, 25_000, false).await?;
+        let xorurl_priv = safe.multimap_create(None, 25_000, true).await?;
 
         let _ = safe.multimap_get_by_key(&xorurl, &key).await?;
         let _ = safe.multimap_get_by_key(&xorurl_priv, &key).await?;
 
         let hash = safe
-            .multimap_insert(&xorurl, key_val.clone(), BTreeSet::new(), false)
+            .multimap_insert(&xorurl, key_val.clone(), BTreeSet::new())
             .await?;
         let hash_priv = safe
-            .multimap_insert(&xorurl_priv, key_val.clone(), BTreeSet::new(), false)
+            .multimap_insert(&xorurl_priv, key_val.clone(), BTreeSet::new())
             .await?;
 
         let received_data = retry_loop_for_pattern!(safe.multimap_get_by_key(&xorurl, &key), Ok(v) if !v.is_empty())?;
@@ -305,16 +302,11 @@ mod tests {
         // Let's now test an insert which replace the previous value for a key
         let hashes_to_replace = vec![hash].into_iter().collect();
         let hash2 = safe
-            .multimap_insert(&xorurl, key_val2.clone(), hashes_to_replace, false)
+            .multimap_insert(&xorurl, key_val2.clone(), hashes_to_replace)
             .await?;
         let hashes_priv_to_replace = vec![hash_priv].into_iter().collect();
         let hash_priv2 = safe
-            .multimap_insert(
-                &xorurl_priv,
-                key_val2.clone(),
-                hashes_priv_to_replace,
-                false,
-            )
+            .multimap_insert(&xorurl_priv, key_val2.clone(), hashes_priv_to_replace)
             .await?;
 
         let received_data = retry_loop_for_pattern!(safe.multimap_get_by_key(&xorurl, &key),
@@ -344,24 +336,24 @@ mod tests {
         let val2 = b"value2".to_vec();
         let key_val2 = (key2.clone(), val2.clone());
 
-        let xorurl = safe.multimap_create(None, 25_000, false, false).await?;
-        let xorurl_priv = safe.multimap_create(None, 25_000, true, false).await?;
+        let xorurl = safe.multimap_create(None, 25_000, false).await?;
+        let xorurl_priv = safe.multimap_create(None, 25_000, true).await?;
 
         let _ = safe.multimap_get_by_key(&xorurl, &key).await?;
         let _ = safe.multimap_get_by_key(&xorurl_priv, &key).await?;
 
         let hash = safe
-            .multimap_insert(&xorurl, key_val.clone(), BTreeSet::new(), false)
+            .multimap_insert(&xorurl, key_val.clone(), BTreeSet::new())
             .await?;
         let hash2 = safe
-            .multimap_insert(&xorurl, key_val2.clone(), BTreeSet::new(), false)
+            .multimap_insert(&xorurl, key_val2.clone(), BTreeSet::new())
             .await?;
 
         let hash_priv = safe
-            .multimap_insert(&xorurl_priv, key_val.clone(), BTreeSet::new(), false)
+            .multimap_insert(&xorurl_priv, key_val.clone(), BTreeSet::new())
             .await?;
         let hash_priv2 = safe
-            .multimap_insert(&xorurl_priv, key_val2.clone(), BTreeSet::new(), false)
+            .multimap_insert(&xorurl_priv, key_val2.clone(), BTreeSet::new())
             .await?;
 
         let received_data = safe.multimap_get_by_hash(&xorurl, hash).await?;
@@ -386,17 +378,17 @@ mod tests {
         let val = b"value".to_vec();
         let key_val = (key.clone(), val.clone());
 
-        let xorurl = safe.multimap_create(None, 25_000, false, false).await?;
-        let xorurl_priv = safe.multimap_create(None, 25_000, true, false).await?;
+        let xorurl = safe.multimap_create(None, 25_000, false).await?;
+        let xorurl_priv = safe.multimap_create(None, 25_000, true).await?;
 
         let _ = retry_loop!(safe.multimap_get_by_key(&xorurl, &key));
         let _ = retry_loop!(safe.multimap_get_by_key(&xorurl_priv, &key));
 
         let hash = safe
-            .multimap_insert(&xorurl, key_val.clone(), BTreeSet::new(), false)
+            .multimap_insert(&xorurl, key_val.clone(), BTreeSet::new())
             .await?;
         let hash_priv = safe
-            .multimap_insert(&xorurl_priv, key_val, BTreeSet::new(), false)
+            .multimap_insert(&xorurl_priv, key_val, BTreeSet::new())
             .await?;
 
         let received_data = retry_loop_for_pattern!(safe.multimap_get_by_key(&xorurl, &key), Ok(v) if !v.is_empty())?;
@@ -410,9 +402,7 @@ mod tests {
         );
 
         let hashes_to_remove = vec![hash].into_iter().collect();
-        let removed_mark_hash = safe
-            .multimap_remove(&xorurl, hashes_to_remove, false)
-            .await?;
+        let removed_mark_hash = safe.multimap_remove(&xorurl, hashes_to_remove).await?;
         assert_ne!(removed_mark_hash, hash);
 
         assert_eq!(
@@ -426,9 +416,7 @@ mod tests {
         assert_eq!((read_hash, read_key_val), (hash_priv, (key.clone(), val)));
 
         let hashes_to_remove = vec![hash_priv].into_iter().collect();
-        let removed_mark_hash = safe
-            .multimap_remove(&xorurl_priv, hashes_to_remove, false)
-            .await?;
+        let removed_mark_hash = safe.multimap_remove(&xorurl_priv, hashes_to_remove).await?;
         assert_ne!(removed_mark_hash, hash_priv);
 
         assert_eq!(
